; *********************************************************************
; *
; * Create a library to store procedure definitions
; *
; *********************************************************************
IF ISASSIGNED(LibDir.A) THEN
   ProcLib.A  = LibDir.A+"Main"
ELSE
   ProcLib.A  = "Main"
ENDIF

CREATELIB ProcLib.A

PROC FlashWait(FWSwitch.L)
; *********************************************************************
; *
; * Puts a flashing WAIT in upper right hand corner like LOTUS
; *
; *********************************************************************
PRIVATE ProcName.A
ProcName.A = "FlashWait"
IF FWSwitch.L THEN
    @ 0,0 ?? SPACES(80)
    @ 1,0 ?? SPACES(80)
    STYLE ATTRIBUTE 207
    @ 0,75 ?? "WAIT"
ELSE
    @ 0,0 ?? SPACES(80)
    @ 1,0 ?? SPACES(80)
    @ 0,75 ?? "    "
ENDIF
    STYLE
ENDPROC ;FlashWait

WRITELIB ProcLib.A FlashWait
RELEASE PROCS FlashWait
MESSAGE "FlashWait Compiled"
;
PROC GetSelectedRecord(SourceFile.F)
; *********************************************************************
; *
; * GetSelectedRecord()
; *
; * Query the database for all records with a checkmark in the [Tag]
; * field
; *
; *********************************************************************
PRIVATE ProcName.A,            ;the name of this procedure
        SourceFile.F           ;source file to query against

ProcName.A="GetSelectedRecord"
CLEARALL
MENU {Ask} SELECT SourceFile.F ;ask for the passed file name
CHECKPLUS                      ;select all fields for answer
MOVETO [Tag]                   ;move to the tag field
"\"\""                        ;and place a literal "" there
DO_IT!

ENDPROC ;GetSelectedRecord()

WRITELIB ProcLib.A GetSelectedRecord
RELEASE PROCS GetSelectedRecord
MESSAGE "GetSelectedRecord Compiled"
;
PROC DisplayAnswer(SourceFile.F,Form.A)
; *********************************************************************
; *
; * DisplayAnswer()
; *
; * Copy the selected form to the answer file and display it
; * return when the user hits [F2]
; *
; *********************************************************************
PRIVATE ProcName.A                 ;the name of this procedure
ProcName.A="DisplayAnswer"

COPYFORM SourceFile.F Form.A "Answer" "F"

VIEW "Answer"
PICKFORM "F"

WAIT TABLE
   PROMPT "View the answer", "Press [F2] to exit"
UNTIL "Do_it!"

ENDPROC ;DisplayAnswer()

WRITELIB ProcLib.A DisplayAnswer
RELEASE PROCS DisplayAnswer
MESSAGE "DisplayAnswer Compiled"
;
PROC PrintAnswer(SourceFile.F,Rpt.A)
; *********************************************************************
; *
; * PrintAnswer()
; *
; * Copy the selected report to the printer and print it
; * no error checking
; *
; *********************************************************************
PRIVATE ProcName.A
ProcName.A="PrintAnswer"

COPYREPORT SourceFile.F Rpt.A "Answer" "R"
REPORT "Answer" "R"

ENDPROC ;PrintAnswer()

WRITELIB ProcLib.A PrintAnswer
RELEASE PROCS PrintAnswer
MESSAGE "PrintAnswer Compiled"
;
PROC ClearTags(SourceFile.F)
; *********************************************************************
; *
; * ClearTags()
; *
; * clear the [Tag] field in preparation for user selection
; *
; *********************************************************************
PRIVATE ProcName.A,
        SourceFile.F           ; source file to query against

ProcName.A="ClearTags"
CLEARALL
MENU {Ask} SELECT SourceFile.F ; query the source file
MOVETO [Tag]
"CHANGETO BLANK"               ; zap the tag field
DO_IT!

ENDPROC ;ClearTags()

WRITELIB ProcLib.A ClearTags
RELEASE PROCS ClearTags
MESSAGE "ClearTags Compiled"
;
PROC SelectTag(FileName.F,Form.A,OneRec.L)
; *********************************************************************
; *
; * SelectTag()
; *
; * present the database to the user so they can select which records
; * to process.
; *
; *********************************************************************
PRIVATE ProcName.A,                ;the name of this procedure
        FileName.A,                ;the file we're going to look at
        Form.A,                    ;the form object we're using
        OK,                        ;is this OK (T/F)
        Choice.A,                  ;save field for retval
        RecNo.N,                   ;number of records in the database
        OneRec.L,                  ;Select one record only? T/F
        TagFlag.L                  ;Has one been tagged already?

ProcName.A="SelectTag"
TagFlag.L = False

COEDIT   FileName.F
PICKFORM Form.A

WHILE True
IMAGERIGHTS READONLY
WAIT TABLE
   PROMPT "Select the items to be worked on - [Esc] to abort",
          "[F5] - Tag, [F6] - UnTag, "
         +"[F7] - Tag All, [F8] - UnTag All, [F2] - Continue"

   UNTIL "F5", "F6", "F7", "F8", "F2", "Esc",
       "GoKey","ReSyncKey","Dos","Rotate","KeyLookup",
       "LockKey","DosBig","Refresh","ShowSQL","FieldView","F35",
       "Do_it!"

Choice.A = Retval
SWITCH
   CASE Choice.A = "F2"
   OR   Choice.A = "Do_it!": OK = True  QUITLOOP   ;we're done, vamoose

   CASE Choice.A = "Esc"   : OK = False QUITLOOP   ;changed our mind
                                                   ;return false

   CASE Choice.A = "F5"    : IF NOT OneRec.L       ;if we can tag more 
                             OR NOT TagFlag.L THEN ;than one or have not 
                               IMAGERIGHTS UPDATE  ;tagged any records yet
                               [Tag] = ""         ;then tag this one
                               TagFlag.L = True
                             else                  ;otherwise...
                               message "Only one record can be tagged"
                             ENDIF


   CASE Choice.A = "F6"    : IMAGERIGHTS UPDATE    ;set image rights
                             [Tag] = ""            ;and blow away this 
                             TagFlag.L = False     ;records tag

   CASE Choice.A = "F7"    : FlashWait(True)       ;tell the user to wait
                             RecNo.N=RECNO()       ;store current record #
                             IMAGERIGHTS UPDATE    ;set imagerights
                             IF OneRec.L THEN      ;if we can only tag one
                               IF TagFlag.L THEN   ;and one hasn't been tagged
                                   [Tag]     = "" ;then tag this one
                                   TagFlag.L = True
                               ENDIF               ;otherwise...
                               message "Only one record can be tagged"
                             ELSE                  ;we CAN tag them all
                               SCAN                ;so set up a scan
                                   [Tag] = ""     ;to do it
                               ENDSCAN
                               MOVETO RECORD RecNo.N   ;back to the record
                             ENDIF                     ;we started from

   CASE Choice.A = "F8"    : FlashWait(True)       ;tell the user to hang in
                             IMAGERIGHTS UPDATE    ;set imagerights
                             RecNo.N=RECNO()       ;store current record #
                             SCAN                  ;set up scan loop
                               [Tag] = ""
                             ENDSCAN
                             MOVETO RECORD RecNo.N ;back to the start record
                             TagFlag.L = False     ;set flag to untagged
ENDSWITCH

LOOP               ;back to "WAIT TABLE"

ENDWHILE           ;end of while loop

DO_IT!             ;save tags

RETURN OK          ;return OK status

ENDPROC ;SelectTag()

WRITELIB ProcLib.A SelectTag
RELEASE PROCS SelectTag
MESSAGE "SelectTag Compiled"
;
PROC Main()
; *********************************************************************
; *
; * Main()
; *
; *********************************************************************
PRIVATE ProcName.A,    ;the name of this procedure
        Opt.A,         ;menu option selected by user
        OK             ;is this OK (T/F)

ProcName.A="Main"

WHILE True
   OK = False
   SHOWMENU
       "Display"   : "Display selected records",
       "Print"     : "Print selected records",
       "Quit"      : "Leave this program"
   TO Opt.A
;*
;* First, use the menu selection to see if we need to tag records
;*
   SWITCH
       CASE Opt.A = "Display"  
         OR Opt.A = "Print"    :ClearTags(Address.F)
                                OK=SelectTag(Address.F,"1",False)
       CASE Opt.A = "Quit"     :QUITLOOP
   ENDSWITCH
;*
;* Next, if OK = True, query the database and display or print
;* as requested
;*
   IF OK THEN
       GetSelectedRecord(Address.F)
       IF NRECORDS("Answer") > 0 THEN
           SWITCH
               CASE Opt.A = "Display"  :DisplayAnswer(Address.F,"F")
               CASE Opt.A = "Print"    :PrintAnswer(Address.F,"R")
           ENDSWITCH
           SETDIR(DIRECTORY())         ;wipe out the "Answer" table
           CLEARALL                    ;after use
       ELSE
           BEEP                            ;no records in answer?
           MESSAGE "No records selected"   ;Let the operator know!
           SLEEP 750                       ;hang msg for 3/4 second
       ENDIF
   ENDIF

ENDWHILE                  
                   
ENDPROC ;Main()

WRITELIB ProcLib.A Main
RELEASE PROCS Main
MESSAGE "Main Compiled"
